==> istio-model-v1beta1-6.7.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsConsistentHashLBBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LoadBalancerSettingsConsistentHashLBBuilder extends LoadBalancerSettingsConsistentHashLBFluentImpl<LoadBalancerSettingsConsistentHashLBBuilder> implements VisitableBuilder<LoadBalancerSettingsConsistentHashLB,LoadBalancerSettingsConsistentHashLBBuilder>{
  public LoadBalancerSettingsConsistentHashLBBuilder() {
    this(false);
  }
  public LoadBalancerSettingsConsistentHashLBBuilder(Boolean validationEnabled) {
    this(new LoadBalancerSettingsConsistentHashLB(), validationEnabled);
  }
  public LoadBalancerSettingsConsistentHashLBBuilder(LoadBalancerSettingsConsistentHashLBFluent<?> fluent) {
    this(fluent, false);
  }
  public LoadBalancerSettingsConsistentHashLBBuilder(LoadBalancerSettingsConsistentHashLBFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LoadBalancerSettingsConsistentHashLB(), validationEnabled);
  }
  public LoadBalancerSettingsConsistentHashLBBuilder(LoadBalancerSettingsConsistentHashLBFluent<?> fluent,LoadBalancerSettingsConsistentHashLB instance) {
    this(fluent, instance, false);
  }
  public LoadBalancerSettingsConsistentHashLBBuilder(LoadBalancerSettingsConsistentHashLBFluent<?> fluent,LoadBalancerSettingsConsistentHashLB instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withHashKey(instance.getHashKey());
      fluent.withMinimumRingSize(instance.getMinimumRingSize());
    }
    this.validationEnabled = validationEnabled; 
  }
  public LoadBalancerSettingsConsistentHashLBBuilder(LoadBalancerSettingsConsistentHashLB instance) {
    this(instance,false);
  }
  public LoadBalancerSettingsConsistentHashLBBuilder(LoadBalancerSettingsConsistentHashLB instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withHashKey(instance.getHashKey());
      this.withMinimumRingSize(instance.getMinimumRingSize());
    }
    this.validationEnabled = validationEnabled; 
  }
  LoadBalancerSettingsConsistentHashLBFluent<?> fluent;
  Boolean validationEnabled;
  public LoadBalancerSettingsConsistentHashLB build() {
    LoadBalancerSettingsConsistentHashLB buildable = new LoadBalancerSettingsConsistentHashLB(fluent.getHashKey(),fluent.getMinimumRingSize());
    return buildable;
  }
  
}

==> istio-model-v1beta1-6.8.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsConsistentHashLBBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LoadBalancerSettingsConsistentHashLBBuilder extends LoadBalancerSettingsConsistentHashLBFluent<LoadBalancerSettingsConsistentHashLBBuilder> implements VisitableBuilder<LoadBalancerSettingsConsistentHashLB,LoadBalancerSettingsConsistentHashLBBuilder>{
  public LoadBalancerSettingsConsistentHashLBBuilder() {
    this(false);
  }
  public LoadBalancerSettingsConsistentHashLBBuilder(Boolean validationEnabled) {
    this(new LoadBalancerSettingsConsistentHashLB(), validationEnabled);
  }
  public LoadBalancerSettingsConsistentHashLBBuilder(LoadBalancerSettingsConsistentHashLBFluent<?> fluent) {
    this(fluent, false);
  }
  public LoadBalancerSettingsConsistentHashLBBuilder(LoadBalancerSettingsConsistentHashLBFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LoadBalancerSettingsConsistentHashLB(), validationEnabled);
  }
  public LoadBalancerSettingsConsistentHashLBBuilder(LoadBalancerSettingsConsistentHashLBFluent<?> fluent,LoadBalancerSettingsConsistentHashLB instance) {
    this(fluent, instance, false);
  }
  public LoadBalancerSettingsConsistentHashLBBuilder(LoadBalancerSettingsConsistentHashLBFluent<?> fluent,LoadBalancerSettingsConsistentHashLB instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new LoadBalancerSettingsConsistentHashLB());

    if (instance != null) {
      fluent.withHashKey(instance.getHashKey());
      fluent.withMinimumRingSize(instance.getMinimumRingSize());
      fluent.withHashKey(instance.getHashKey());
      fluent.withMinimumRingSize(instance.getMinimumRingSize());
    }
    this.validationEnabled = validationEnabled; 
  }
  public LoadBalancerSettingsConsistentHashLBBuilder(LoadBalancerSettingsConsistentHashLB instance) {
    this(instance,false);
  }
  public LoadBalancerSettingsConsistentHashLBBuilder(LoadBalancerSettingsConsistentHashLB instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new LoadBalancerSettingsConsistentHashLB());

    if (instance != null) {
      this.withHashKey(instance.getHashKey());
      this.withMinimumRingSize(instance.getMinimumRingSize());
      this.withHashKey(instance.getHashKey());
      this.withMinimumRingSize(instance.getMinimumRingSize());
    }
    this.validationEnabled = validationEnabled; 
  }
  LoadBalancerSettingsConsistentHashLBFluent<?> fluent;
  Boolean validationEnabled;
  public LoadBalancerSettingsConsistentHashLB build() {
    LoadBalancerSettingsConsistentHashLB buildable = new LoadBalancerSettingsConsistentHashLB(fluent.buildHashKey(),fluent.getMinimumRingSize());
    return buildable;
  }
  
}
